# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/rugbypy',
                'doc_host': 'https://seanyboi.github.io',
                'git_url': 'https://github.com/seanyboi/rugbypy',
                'lib_path': 'rugbypy'},
  'syms': { 'rugbypy.competition': { 'rugbypy.competition.fetch_all_competitions': ( 'competition.html#fetch_all_competitions',
                                                                                     'rugbypy/competition.py')},
            'rugbypy.match': { 'rugbypy.match.fetch_all_matches': ('match.html#fetch_all_matches', 'rugbypy/match.py'),
                               'rugbypy.match.fetch_match_details': ('match.html#fetch_match_details', 'rugbypy/match.py'),
                               'rugbypy.match.fetch_matches': ('match.html#fetch_matches', 'rugbypy/match.py'),
                               'rugbypy.match.fetch_matches_by_date': ('match.html#fetch_matches_by_date', 'rugbypy/match.py')},
            'rugbypy.player': { 'rugbypy.player.cosine_similarity': ('player.html#cosine_similarity', 'rugbypy/player.py'),
                                'rugbypy.player.fetch_all_players': ('player.html#fetch_all_players', 'rugbypy/player.py'),
                                'rugbypy.player.fetch_player_id': ('player.html#fetch_player_id', 'rugbypy/player.py'),
                                'rugbypy.player.fetch_player_stats': ('player.html#fetch_player_stats', 'rugbypy/player.py'),
                                'rugbypy.player.word2vec': ('player.html#word2vec', 'rugbypy/player.py')},
            'rugbypy.team': { 'rugbypy.team.fetch_all_teams': ('team.html#fetch_all_teams', 'rugbypy/team.py'),
                              'rugbypy.team.fetch_team_stats': ('team.html#fetch_team_stats', 'rugbypy/team.py')},
            'rugbypy.venue': {'rugbypy.venue.fetch_all_venues': ('venue.html#fetch_all_venues', 'rugbypy/venue.py')}}}
